HorizontalScroller<T> class

A robust, plug-and-play horizontal auto-scrolling widget Optimized for iOS and Android with configurable options

Inheritance

Constructors

HorizontalScroller({Key? key, required List<T> items, required Widget itemBuilder(T item, int index), double height = 80.0, double? customWidth, EdgeInsets margin = const EdgeInsets.symmetric(vertical: 15), bool enableAutoScroll = true, double scrollSpeed = 50.0, bool enableInfiniteScroll = true, Duration? startDelay, bool enableClick = true, bool enableRipple = true, dynamic onItemClick(T item, int index)?, Color? backgroundColor = Colors.black, EdgeInsets itemPadding = const EdgeInsets.only(left: 15)})
const

Properties

backgroundColor Color?
final
customWidth double?
final
enableAutoScroll bool
final
enableClick bool
final
enableInfiniteScroll bool
final
enableRipple bool
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
itemBuilder Widget Function(T item, int index)
final
itemPadding EdgeInsets
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsets
final
onItemClick → dynamic Function(T item, int index)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollSpeed double
final
startDelay Duration?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<HorizontalScroller<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited